@@ -1,6 +1,6 @@
 from .csv_crf_inline_tables_exporter import CsvCrfInlineTablesExporter
 from .csv_crf_tables_exporter import CsvCrfTablesExporter
-from .csv_exporter import CsvExporter
+from .csv_exporter import CsvExporter, Exporter
 from .csv_model_exporter import CsvModelExporter
 from .csv_noncrf_tables_exporter import CsvNonCrfTablesExporter
 from .tables_exporter import TablesExporter
